@@ -16,6 +16,9 @@ import mock
 import time
 import re
 import subprocess
+import pathlib
+import warnings
+from collections import namedtuple
 
 import pytest
 from jaraco import path
@@ -659,7 +662,7 @@ class TestSetupRequires:
                 dep_url = path_to_url(dep_sdist, authority='localhost')
                 test_pkg = create_setup_requires_package(
                     temp_dir,
-                    # Ignored (overriden by setup_attrs)
+                    # Ignored (overridden by setup_attrs)
                     'python-xlib', '0.19',
                     setup_attrs=dict(
                         setup_requires='dependency @ %s' % dep_url))
@@ -669,26 +672,24 @@ class TestSetupRequires:
 
     def test_setup_requires_with_allow_hosts(self, mock_index):
         ''' The `allow-hosts` option in not supported anymore. '''
+        files = {
+            'test_pkg': {
+                'setup.py': DALS('''
+                    from setuptools import setup
+                    setup(setup_requires='python-xlib')
+                    '''),
+                'setup.cfg': DALS('''
+                    [easy_install]
+                    allow_hosts = *
+                    '''),
+            }
+        }
         with contexts.save_pkg_resources_state():
             with contexts.tempdir() as temp_dir:
-                test_pkg = os.path.join(temp_dir, 'test_pkg')
-                test_setup_py = os.path.join(test_pkg, 'setup.py')
-                test_setup_cfg = os.path.join(test_pkg, 'setup.cfg')
-                os.mkdir(test_pkg)
-                with open(test_setup_py, 'w') as fp:
-                    fp.write(DALS(
-                        '''
-                        from setuptools import setup
-                        setup(setup_requires='python-xlib')
-                        '''))
-                with open(test_setup_cfg, 'w') as fp:
-                    fp.write(DALS(
-                        '''
-                        [easy_install]
-                        allow_hosts = *
-                        '''))
+                path.build(files, prefix=temp_dir)
+                setup_py = str(pathlib.Path(temp_dir, 'test_pkg', 'setup.py'))
                 with pytest.raises(distutils.errors.DistutilsError):
-                    run_setup(test_setup_py, [str('--version')])
+                    run_setup(setup_py, [str('--version')])
         assert len(mock_index.requests) == 0
 
     def test_setup_requires_with_python_requires(self, monkeypatch, tmpdir):
@@ -731,7 +732,7 @@ class TestSetupRequires:
         with contexts.save_pkg_resources_state():
             test_pkg = create_setup_requires_package(
                 str(tmpdir),
-                'python-xlib', '0.19',  # Ignored (overriden by setup_attrs).
+                'python-xlib', '0.19',  # Ignored (overridden by setup_attrs).
                 setup_attrs=dict(
                     setup_requires='dep', dependency_links=[index_url]))
             test_setup_py = os.path.join(test_pkg, 'setup.py')
@@ -1059,3 +1060,50 @@ class TestWindowsScriptWriter:
         hdr = hdr.rstrip('\n')
         # header should not start with an escaped quote
         assert not hdr.startswith('\\"')
+
+
+VersionStub = namedtuple("VersionStub", "major, minor, micro, releaselevel, serial")
+
+
+@pytest.mark.skipif(
+    os.name == 'nt',
+    reason='Installation schemes for Windows may use values for interpolation '
+    'that come directly from sysconfig and are difficult to patch/mock'
+)
+def test_use_correct_python_version_string(tmpdir, tmpdir_cwd, monkeypatch):
+    # In issue #3001, easy_install wrongly uses the `python3.1` directory
+    # when the interpreter is `python3.10` and the `--user` option is given.
+    # See pypa/setuptools#3001.
+    dist = Distribution()
+    cmd = dist.get_command_obj('easy_install')
+    cmd.args = ['ok']
+    cmd.optimize = 0
+    cmd.user = True
+    cmd.install_userbase = str(tmpdir)
+    cmd.install_usersite = None
+    install_cmd = dist.get_command_obj('install')
+    install_cmd.install_userbase = str(tmpdir)
+    install_cmd.install_usersite = None
+
+    with monkeypatch.context() as patch, warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        version = '3.10.1 (main, Dec 21 2021, 09:17:12) [GCC 10.2.1 20210110]'
+        info = VersionStub(3, 10, 1, "final", 0)
+        patch.setattr('site.ENABLE_USER_SITE', True)
+        patch.setattr('sys.version', version)
+        patch.setattr('sys.version_info', info)
+        patch.setattr(cmd, 'create_home_path', mock.Mock())
+        cmd.finalize_options()
+
+    if os.getenv('SETUPTOOLS_USE_DISTUTILS', 'local') == 'local':
+        # Installation schemes in stdlib distutils might be outdated/bugged
+        name = "pypy" if hasattr(sys, 'pypy_version_info') else "python"
+        install_dir = cmd.install_dir.lower()
+        assert f"{name}3.10" in install_dir or f"{name}310" in install_dir
+
+    # The following "variables" are used for interpolation in distutils
+    # installation schemes, so it should be fair to treat them as "semi-public",
+    # or at least public enough so we can have a test to make sure they are correct
+    assert cmd.config_vars['py_version'] == '3.10.1'
+    assert cmd.config_vars['py_version_short'] == '3.10'
+    assert cmd.config_vars['py_version_nodot'] == '310'
